.First.lib <- function(lib, pkg) {
  if(version$major<2)
    stop("This version is for R 2.6.0 or later")
# require( nlme )
# require( R2WinBUGS )
# require( coda )
}
